-- This Source Code Form is subject to the terms of the bCDDL, v. 1.1.
-- If a copy of the bCDDL was not distributed with this
-- file, You can obtain one at http://beamng.com/bCDDL-1.1.txt

local M = {}

local message = false
local oldHSDAV = 0
local oldHSUAV = 0
local oldLSDAV = 0
local oldLSUAV = 0

local function onInit()
    oldHSDAV = v.data.engine.highShiftDownAV
    oldHSUAV = v.data.engine.highShiftUpAV
    oldLSDAV = v.data.engine.lowShiftDownAV
    oldLSUAV = v.data.engine.lowShiftUpAV
end

local function updateGFX(dt)
    local engine = v.data.engine
    if engine.dct then
        --dual clutch transmission (DCT)
        --disallow full manual
        --automatic mode
        if drivetrain.shifterMode == 0 then
            drivetrain.shifterMode = 3
            drivetrain.autoClutch = true
            drivetrain.manualShift = false
            if message == false then
                gui.message("Real automatic", 5, "shiftermode")
                message = true
            end
        else
            message = false
        end
        --disallow manual 1st and 2nd gear
        if drivetrain.shifterMode == 3 then
            if drivetrain.shifterPosition > 1 then 
                drivetrain.shifterPosition = 1
            end
        end
        --prevent upshifting while braking
        if input.brake > 0.7 then
            engine.lowShiftDownAV = oldHSDAV
            engine.lowShiftUpAV = oldHSUAV
        else
            engine.lowShiftDownAV = oldLSDAV
            engine.lowShiftUpAV = oldLSUAV
        end
        --prevent chaotic shifting on hard launches
        if electrics.values['wheelspeed'] < 15 and drivetrain.gear < 1.5 and drivetrain.gear > 0.5 and input.throttle > 0.9 then
            engine.highShiftDownAV = 300
            engine.highShiftUpAV = 845
        else
            engine.highShiftDownAV = oldHSDAV
            engine.highShiftUpAV = oldHSUAV
        end
        --don't allow car to be above redline
        if drivetrain.gear < engine.fwdGearCount and drivetrain.gear > 0 and drivetrain.rpm > (engine.maxRPM + 1500) then
            drivetrain.gear = drivetrain.gear + 1
            drivetrain.shifterPosition = drivetrain.shifterPosition + 1
        end
    end
end

-- public interface
M.onInit      = onInit
M.updateGFX = updateGFX

return M