-- This Source Code Form is subject to the terms of the bCDDL, v. 1.1.
-- If a copy of the bCDDL was not distributed with this
-- file, You can obtain one at http://beamng.com/bCDDL-1.1.txt
local M = {}

local speedThresholdNormalPosition = 23
local speedThresholdClosedPosition = 12
local speedThresholdBrakingPosition = 8
local brakeThresholdBrakingPosition = 0.5
local spoiler = 0

local spoilerClosed = 0
local spoilerNormal = 0.75
local spoilerBraking = 1

local function onInit()
    electrics.values['spoiler'] = 0
end

local function reset()
    onInit()
end

local function updateGFX(dt)
    local currentSpoiler = electrics.values['spoiler'] --read current spoiler setting
    local speed = electrics.values['airspeed'] --read wheelspeed
    
    if electrics.values['brake'] > brakeThresholdBrakingPosition then --check for brake input
        if speed >= speedThresholdBrakingPosition then --set braking position if we are above the braking threhsold speed
            spoiler = spoilerBraking --(we are braking and our speed is high -> fully open spoiler)
        else
            spoiler = spoilerClosed --close the spoiler if below (we are still braking, but our speed is very low, no need for the spoiler)
        end
    elseif speed >= speedThresholdNormalPosition then --we are not braking, check for normal spoiler mode speed
        spoiler = spoilerNormal --(we are above the normal spoiler position speed, so set the spoiler to normal)
    else --we are not braking AND below the normal position speed
        if currentSpoiler == spoilerNormal and speed >= speedThresholdClosedPosition then --check if our spoiler is currently in the normal position and we are still above the closed position speed threshold
            spoiler = spoilerNormal --(we are BELOW the normal position speed but out spoiler is open and we want to keep it that way until we are below the closing speed)
        else
            spoiler = spoilerClosed --(we are just very slow, nothing else, so close that spoiler)
        end
    end
        
    --spoiler = spoilerNormal
    --push value
    electrics.values['spoiler'] = spoiler
end

-- public interface
M.onInit    = onInit
M.reset     = reset
M.updateGFX = updateGFX

return M